@@ -4,10 +4,10 @@ use Modern::Perl;
 package SVN::Simple::Hook;
 use strict;
 
-our $VERSION = '0.309';    # VERSION
+our $VERSION = '0.312';    # VERSION
 use Any::Moose '::Role';
-use Any::Moose 'X::Types::' . any_moose() => ['Str'];
-use Any::Moose 'X::Types::Path::Class'    => ['Dir'];
+use Any::Moose 'X::Types::Moose'       => ['Str'];
+use Any::Moose 'X::Types::Path::Class' => ['Dir'];
 use List::MoreUtils 'any';
 use Path::Class;
 use Try::Tiny;
@@ -65,7 +65,7 @@ has paths_changed => (
     builder  => '_build_paths_changed',
 );
 
-sub _build_paths_changed {    ## no critic (ProhibitUnusedPrivateSubroutines)
+sub _build_paths_changed {
     my $self = shift;
     my $root = $self->root;
     my $fs   = $root->fs;
@@ -126,7 +126,7 @@ SVN::Simple::Hook - Simple Moose/Mouse-based framework for Subversion hooks
 
 =head1 VERSION
 
-version 0.309
+version 0.312
 
 =head1 SYNOPSIS
 
